@@ -1,5 +1,7 @@
 import gtk
 import hildon
+import gobject
+import evolution
 from ctypes import *
 from pygobject import *
 
@@ -16,7 +18,7 @@ class ContactView(hildon.PannableArea):
     
     hildon.PannableArea.__init__(self)
     self.contacts = contacts
-    self.treestore = gtk.ListStore(str, gtk.gdk.Pixbuf)
+    self.treestore = gtk.ListStore(str, gtk.gdk.Pixbuf, gobject.TYPE_PYOBJECT)
     for contact in self.contacts:
       if not contact.get_name():
         continue
@@ -37,7 +39,7 @@ class ContactView(hildon.PannableArea):
       if pixbuf:
         size = min(pixbuf.get_width(), pixbuf.get_height())
         pixbuf = pixbuf.subpixbuf(0, 0, size, size).scale_simple(48, 48, gtk.gdk.INTERP_BILINEAR)
-      self.treestore.append(row = [contact.get_name(), pixbuf])
+      self.treestore.append(row = [contact.get_name(), pixbuf, contact])
 
     self.treeview = gtk.TreeView(self.treestore)
     tvcolumn = gtk.TreeViewColumn('Name', gtk.CellRendererText(), text = 0)
@@ -47,7 +49,24 @@ class ContactView(hildon.PannableArea):
     cell.set_property('xalign', 1.0)
     tvcolumn = gtk.TreeViewColumn('Picture', cell, pixbuf = 1)
     self.treeview.append_column(tvcolumn)
-
+    
+    self.treeview.set_search_column(0)
+    self.treeview.connect('row-activated', self._activated)
     self.add(self.treeview)
     self.set_size_request(600, 380)
+    
+    
+  # -----------------------------------------------------------------------
+  def _activated(self, treeview, path, column):
+    """Used to emit the `contact-activated' signal once a row has been
+       selected."""
+       
+    iter    = treeview.get_model().get_iter(path)
+    contact = treeview.get_model().get_value(iter, 2)
+    self.emit('contact-activated', contact)
+
+
+_contact_activated = gobject.signal_new('contact-activated', ContactView, gobject.SIGNAL_ACTION, gobject.TYPE_NONE, [gobject.TYPE_PYOBJECT])
+
+
 
